@@ -1,20 +1,25 @@
+import django
 from django import forms
+import decimal
 
 from .widgets import (TextInput, HiddenInput, CheckboxInput, Select,
                       ClearableFileInput, SelectMultiple, DateInput,
                       DateTimeInput, TimeInput, URLInput, NumberInput,
                       EmailInput, NullBooleanSelect, SlugInput, IPAddressInput,
-                      SplitDateTimeWidget, SplitHiddenDateTimeWidget)
+                      SplitDateTimeWidget, SplitHiddenDateTimeWidget,
+                      MultipleHiddenInput)
 
 __all__ = (
     'Field', 'CharField', 'IntegerField', 'DateField', 'TimeField',
     'DateTimeField', 'EmailField', 'FileField', 'ImageField', 'URLField',
     'BooleanField', 'NullBooleanField', 'ChoiceField', 'MultipleChoiceField',
-    'FloatField', 'DecimalField', 'SlugField', 'RegexField', 'IPAddressField',
+    'FloatField', 'DecimalField', 'SlugField', 'RegexField',
     'GenericIPAddressField', 'TypedChoiceField', 'FilePathField',
     'TypedMultipleChoiceField', 'ComboField', 'MultiValueField',
     'SplitDateTimeField',
 )
+if django.VERSION < (1, 9):
+    __all__ += ('IPAddressField',)
 
 
 class Field(forms.Field):
@@ -65,6 +70,7 @@ class ImageField(Field, forms.ImageField):
 
 class MultipleChoiceField(Field, forms.MultipleChoiceField):
     widget = SelectMultiple
+    hidden_widget = MultipleHiddenInput
 
 
 class TypedMultipleChoiceField(MultipleChoiceField,
@@ -87,6 +93,16 @@ class TimeField(Field, forms.TimeField):
 class FloatField(Field, forms.FloatField):
     widget = NumberInput
 
+    def widget_attrs(self, widget):
+        attrs = super(FloatField, self).widget_attrs(widget) or {}
+        if self.min_value is not None:
+            attrs['min'] = self.min_value
+        if self.max_value is not None:
+            attrs['max'] = self.max_value
+        if 'step' not in widget.attrs:
+            attrs.setdefault('step', 'any')
+        return attrs
+
 
 class IntegerField(Field, forms.IntegerField):
     widget = NumberInput
@@ -111,6 +127,16 @@ class DecimalField(Field, forms.DecimalField):
         kwargs.setdefault('widget', NumberInput if not kwargs.get('localize') else self.widget)
         super(DecimalField, self).__init__(*args, **kwargs)
 
+    def widget_attrs(self, widget):
+        attrs = super(DecimalField, self).widget_attrs(widget) or {}
+        if self.min_value is not None:
+            attrs['min'] = self.min_value
+        if self.max_value is not None:
+            attrs['max'] = self.max_value
+        if self.decimal_places is not None:
+            attrs['step'] = decimal.Decimal('0.1') ** self.decimal_places
+        return attrs
+
 
 class EmailField(Field, forms.EmailField):
     widget = EmailInput
@@ -140,8 +166,9 @@ class RegexField(Field, forms.RegexField):
         return attrs
 
 
-class IPAddressField(Field, forms.IPAddressField):
-    widget = IPAddressInput
+if django.VERSION < (1, 9):
+    class IPAddressField(Field, forms.IPAddressField):
+        widget = IPAddressInput
 
 
 class GenericIPAddressField(Field, forms.GenericIPAddressField):
