@@ -221,6 +221,10 @@ class ClearableFileInput(FileInput):
     template_name = 'floppyforms/clearable_input.html'
     omit_value = False
 
+    initial_text = _('Currently')
+    input_text = _('Change')
+    clear_checkbox_label = _('Clear')
+
     def clear_checkbox_name(self, name):
         return name + '-clear'
 
@@ -232,6 +236,9 @@ class ClearableFileInput(FileInput):
                                                               attrs)
         ccb_name = self.clear_checkbox_name(name)
         context.update({
+            'clear_checkbox_label': self.clear_checkbox_label,
+            'initial_text': self.initial_text,
+            'input_text': self.input_text,
             'checkbox_name': ccb_name,
             'checkbox_id': self.clear_checkbox_id(ccb_name),
         })
@@ -443,13 +450,7 @@ class CheckboxInput(Input, forms.CheckboxInput):
         return value
 
     def value_from_datadict(self, data, files, name):
-        if name not in data:
-            return False
-        value = data.get(name)
-        values = {'true': True, 'false': False}
-        if isinstance(value, six.string_types):
-            value = values.get(value.lower(), value)
-        return value
+        return forms.CheckboxInput.value_from_datadict(self, data, files, name)
 
     if django.VERSION < (1, 6):
         def _has_changed(self, initial, data):
